@@ -262,7 +262,7 @@ impl GeneralReadout for MacOSGeneralReadout {
         )))
     }
 
-    fn local_ip(&self, interface: String) -> Result<String, ReadoutError> {
+    fn local_ip(&self, interface: Option<String>) -> Result<String, ReadoutError> {
         crate::shared::local_ip(interface)
     }
 
